# coding: utf-8


#common molecules
class common_molecules:
    def __init__(self):
        self.m = {}
        
        self.salt = molecule("Na:1,Cl:1", "salt")
        self.m["salt"] = self.salt
        
        self.water = molecule("H:2,O:1", "water")
        self.m["water"] = self.water
        
        self.glucose = molecule("C:6,H:12,O:6", "glucose")
        self.m["glucose"] = self.glucose
        
        self.methane = molecule("C:1,H:4", "methane")
        self.m["methane"] = self.methane

        self.silica = molecule("Si:1,O:2", "silica")
        self.m["silica"] = self.silica

        self.baking_soda = molecule("Na:1,H:1,C:1,O:3", "baking_soda")
        self.m["baking_soda"] = self.baking_soda

        self.carbon_dioxide = molecule("C:1,O:2", "carbon_dioxide")
        self.m["carbon_dioxide"] = self.carbon_dioxide

        self.hydrochloric_acid = molecule("H:1,Cl:1", "hydrochloric_acid")
        self.m["hydrochloric_acid"] = self.hydrochloric_acid

    def list_all_molecules(self):
        print "Molecules in database"
        for i,n in enumerate(self.m):
            #print i,n
            print "{f} : {n}".format(n=self.m[n].formula, f=n)

        


#end common molecules

#begin reactions
            
class reactant:
    def __init__(self, stoic, molecule):
        self.stoic = int(stoic)
        self.molecule = molecule


class reaction:
    def __init__(self):
        
        self.reactants = []
        self.products = []

    def add_reactant(self, molecule, stoic=1):
        self.reactants.append(reactant(stoic, molecule))

    def add_product(self, molecule, stoic=1):
        self.products.append(reactant(-int(stoic), molecule))

    def print_reaction(self):
        t = ""
        for i in self.reactants:
            if i.stoic <> 1:
                t += str(i.stoic) + " "
            t += i.molecule.print_formula() + " + "
        t = t[:-2]
        t += " --> "
                            
        for i in self.products:
            if i.stoic <> -1:
                t += str(-i.stoic) + " "
            t += i.molecule.print_formula() + " + "
        t = t[:-2]
        return t

    def check_for_balance(self, printout=False):
        relem = []
        rn = []
        # count atoms in reactants
        for i in self.reactants:
            for e in i.molecule.elements:
                #add element if it's not already in list
                try:
                    ind = relem.index(e.element)
                    rn[ind] += i.stoic*e.anum
                    #print "x",e.element, relem.index(e.element)
                    #print 
                except: 
                    relem.append(e.element)
                    rn.append(i.stoic*e.anum)
                    #print "y",e.element
        #pelem = []
        #pelem[:] = relem[:]
        pn = []
        for i in rn:
            pn.append(0)
        # count atoms in reactants
        for i in self.products:
            for e in i.molecule.elements:
                #add element if it's not already in list
                try:
                    ind = relem.index(e.element)
                    pn[ind] += i.stoic*e.anum
                    #print "x",e.element, relem.index(e.element)
                    #print 
                except: 
                    print "Extra element in products"
        '''
        print "reactants",
        print relem
        print rn
        print "products",
        print pn
        '''

        #check for balance
        l_balance = True
        if (printout):
            print "Check for balance"
            print " --------------------------------------------- "
            print "| Element | Reactants | Products | Difference |"
            print " --------------------------------------------- "
        for i,n in enumerate(relem):
            if (printout):
                print "|   {e}   |    {r}    |    {p}   |     {d}    |".format(e=relem[i].ljust(3), r=str(rn[i]).ljust(3), p=str(pn[i]).ljust(3), d=str(pn[i]+rn[i]).ljust(3))
            if rn[i] <> -pn[i]:
                l_balance = False
                #print relem[i], " out of balance"
                #print "  in reactants: ", rn[i]
                #print "  in products:  ", pn[i]
        if (printout):
            print " --------------------------------------------- "
            print "Balance is: ", l_balance
   
        return l_balance

    def limited_by_mass(self, limiting_molecule, mass, printout=False):
        #limiting_molecule is instance of molecule class
        #mass in grams
        lm = limiting_molecule
        # find the index of the limiting molecule
        for i,r in enumerate(self.reactants):
            #print r.molecule.print_formula(), lm.print_formula(), lm == r.molecule
            if lm.print_formula() == r.molecule.print_formula():
                lim_side = self.reactants
                lim_i = i
        for i,r in enumerate(self.products):
            #print r.molecule.print_formula(), lm.print_formula(), lm == r.molecule
            if lm.print_formula() == r.molecule.print_formula():
                lim_side = self.products
                lim_i = i
        try:        
            lim_side[lim_i].mass = mass
        except:
            print lm, " is not identified as part of this reaction (check the formula)"
            return

        if printout:
            print
            print "Given: Limiting component is {g} g of {m}.".format(m=lim_side[lim_i].molecule.print_formula(),g=lim_side[lim_i].mass)
                
                
        # calculate number of moles of limiting reactant
        lim_moles = lim_side[lim_i].mass / lim_side[lim_i].molecule.molar_mass
        lim_side[lim_i].moles = lim_moles
        if printout:
            print "  Molar mass = {n}".format(n=lim_side[lim_i].molecule.molar_mass)
            print "  Moles of {m} = {n}".format(m=lim_side[lim_i].molecule.print_formula(),n=lim_moles)
        
        # calculate number of moles of other reactants and products needed
        rmass = 0.
        pmass = 0.
        for r in self.reactants:
            mole_ratio = r.stoic / lim_side[lim_i].stoic
            r.moles = lim_side[lim_i].moles * mole_ratio
            r.mass = r.moles * r.molecule.molar_mass
            rmass += r.mass
        for r in self.products:
            mole_ratio = r.stoic / lim_side[lim_i].stoic
            r.moles = lim_side[lim_i].moles * mole_ratio
            r.mass = r.moles * r.molecule.molar_mass
            pmass += r.mass

        if printout:
            print
            print " Results"
            print "   ------------------------------------------------------------------ "
            print "  | Molecule | Stoich.*| Molar Mass (g) | Moles req. |    Mass (g)   |"
            print "   ------------------------------------------------------------------ "
            for r in self.reactants:
                print "  |{m}|    {s}|   {mm:8.4f}     |  {mol:.3e} |   {mass:.3e}   |".format(m=r.molecule.print_formula().ljust(10),
                                                      s=str(r.stoic).ljust(5),
                                                      mm=r.molecule.molar_mass,
                                                      mol=abs(r.moles),
                                                      mass=abs(r.mass))
            for r in self.products:
                print "  |{m}|    {s}|   {mm:8.4f}     |  {mol:.3e} |   {mass:.3e}   |".format(m=r.molecule.print_formula().ljust(10),
                                                      s=str(r.stoic).ljust(5),
                                                      mm=r.molecule.molar_mass,
                                                      mol=abs(r.moles),
                                                      mass=abs(r.mass))
            print "   ------------------------------------------------------------------ "
            print " * negative stoichiometry means the component is a product"
            print
            print "  Final Check: Confirm Mass balance: "
            print "     Reactants:  {r:8.4f} g ".format(r=rmass)
            print "     Products:   {p:8.4f} g ".format(p=pmass)
            print "     --------------------------"
            print "          =    {d:8.4f} g ".format(d=rmass+pmass)
            print "     --------------------------"
            print 
        return

         
                            
        
# end reactions



# begin molecules
class element:
    def __init__(self):
        a = 1

    def print_data(self):
        print "Element: {e}".format(e=self.element)
        for i,n in enumerate(vars(self)):
            print i,n, vars(self)[n]

class epair:
    def __init__(self, pair):
        self.element = pair[0].strip()
        self.anum = int(pair[1])

class molecule:
    def __init__(self, formula, name="Unnamed", printout=False):
        '''formula is a set of element/number-of-atoms pairs'''
        ''' e.g.  "Na:2,O:1" for Na2O'''
        self.formula = formula
        self.name = name
        self.elements = []
        pairs = formula.split(",")
        for e in pairs:
            self.elements.append(epair(e.split(":")))
            #print self.elements[-1].element, self.elements[-1].anum
        self.calc_mass(printout)
        self.all_percent_by_mass()

    def print_formula_f(self):
        n = ""
        for i in self.elements:
            #print i
            n += i.element+":"+str(i.anum)+","
        return n[:-1]

    def print_formula(self):
        n = ""
        for i in self.elements:
            #print i
            n += i.element
            if i.anum > 1:
                n += str(i.anum)
        return n


    def calc_mass(self, printout=False):
        self.molar_mass = 0
        if printout:
            print "CALCULATING MOLAR MASS"
            print "  Formula: {formula},  Name: {name}".format(name=self.name, formula=self.formula)
        for i in self.elements:
            if printout:
                print "  {e}: {n} x {m} = {tm}".format(e=i.element, n=i.anum, m=elements[i.element].weight, tm=elements[i.element].weight * i.anum) #i.element, elements[i.element].weight, i.anum
            self.molar_mass += elements[i.element].weight * i.anum
        if printout:
            print "  Molar Mass = {mass} g\n".format(mass=self.molar_mass)
        return self.molar_mass

    def all_percent_by_mass(self, printout=False):
        tot_percent = 0.
        if printout:
            print "CALCULATING PERCENT BY MASS"
        for i in self.elements:
            i.percent_by_mass = self.percent_by_mass(i.element)
            tot_percent += i.percent_by_mass
            if printout:
                print "  Percent by mass of {element} = {pct}%".format(element=i.element, pct=i.percent_by_mass)
        if printout:
            print "  Total percent = ", tot_percent, "%"

    def percent_by_mass(self, element):
        pm = 0.0
        for i in self.elements:
            if (i.element == element):
                pm = (100. * elements[element].weight * i.anum) / self.molar_mass
        return pm
    
    def moles_to_mass(self, moles):
        m = moles * self.molar_mass
        return m
    def mass_to_moles(self, mass):
        mol = mass / self.molar_mass
        return mol

    def make_molar_solution(self, conc, vol_water, printout=False):
        # NOTE THE UNITS: output in GRAMS.
        # conc = concentration of solution (in moles/liter)
        # vol_water = volume of water to be used (in milliliters)
        g = self.molar_mass * conc * (vol_water /1000.)
        if printout:
            print "MAKING A {c} MOLAR SOLUTION OF {n}:\n".format(c=conc, n=self.name)
            print "  Result:  {g} g of solute ({f}/{n}) ".format(g=g, f=self.formula, n=self.name)
            print "         + {v} milliliters of water ".format(v=vol_water)
            print "  to make a solution with a concentration of {c} moles/liter".format(c=conc) 
            print "  this will have a concentration of {c} grams/liter".format(c=conc/self.molar_mass) 
        return g
        

def parse_molecule(molecule_formula):
    elements = []
    n = []
    plevel = []     #parenthesis level
    pct = 1         #parenthesis count
    pclose = {}
    l_pclose = False
    
    for i in molecule_formula:
        #print i
        if i.isupper():
            print " ", i
            elements.append(i)
            n.append("")
            plevel.append(pct)
            l_pclose = False
        elif i.islower():
            elements[-1] += i
        elif i in "0123456789":
            if l_pclose:
                pclose[pct+1] += i
            else:
                n[-1] += i
        elif i == "(":
            pct += 1
            l_pclose = False
        elif i == ")":
            l_pclose = True
            pclose[pct] = ""
            pct -= 1
        print elements[-1], n[-1], plevel[-1], pct


    for e,i in enumerate(elements):
        if n[e] == "":
            n[e] = 1
        else:
            n[e] = int(n[e])

    for e,i in enumerate(pclose):
        print "e,i", e,i
        if pclose[i] == "":
            pclose[i] = 1
        else:
            pclose[i] = int(pclose[i])

    print pclose, plevel

    for i,j in enumerate(pclose):
        print "pclose: ", i, j, pclose[j]
        for p,q in enumerate(plevel):
            print "p,q",p, q, "plevel[j],j",plevel[j],j
            if plevel[j] == q:
                n[p] = n[p] * pclose[j]

    molform = ""
    for e,i in enumerate(elements):
        print elements[e], n[e]
        molform += "{e}:{n},".format(e=elements[e], n=n[e])
    molform = molform[:-1]
    print molform
    return molecule(molform, name=molecule_formula)


def parse_molecule2(molecule_formula):
    n = []
    plevel = []     #parenthesis level
    pct = 1         #parenthesis count
    parr = [[],]       #parenthesis array
    op_n = 0
    p_stoic = []
    pclose = {}
    l_pclose = False

    print "parr", parr

    #count elements and parenthesis
    elements = []
    nelements = 0
    npars = 1
    for i in molecule_formula:
        if i.isupper():
            elements.append(i)
            nelements += 1
        elif i.islower():
            elements[-1] += i
        elif i == "(":
            npars += 1
            

    print "Elements in molecule: ", nelements, npars, elements
    # build element stoichiometry and parenthesis arrays
    parr = []
    el_stoic = []
    for i in range(nelements):
        el_stoic.append(1)
        #live_pars.append(0)
        parr.append([])
        for j in range(npars):
            parr[-1].append(0)
            
    print parr

    #figure out stoic
    el_num = -1
    par_num = 0
    live_pars = [1,]
    el_stoic = []
    for i in molecule_formula:
        #print i
        if i.isupper():
            print " ", i
            el_num += 1
            for j in range(live_pars):
                parr[el_num][j] = par_num+1
            l_pclose = False
        elif i == "(":
            op_n += 1
            par_num += 1
            live_pars.append(1)
            l_pclose = False
        elif i == ")":
            l_pclose = True
            op_n -= 1
            #pclose[pct] = ""
            #pct -= 1
        elif i in "0123456789":
            if l_pclose:
                pclose[pct+1] += i
            else:
                n[-1] += i
        print elements[-1], n[-1], plevel[-1], pct


    for e,i in enumerate(elements):
        if n[e] == "":
            n[e] = 1
        else:
            n[e] = int(n[e])

    for e,i in enumerate(pclose):
        print "e,i", e,i
        if pclose[i] == "":
            pclose[i] = 1
        else:
            pclose[i] = int(pclose[i])

    print pclose, plevel

    for i,j in enumerate(pclose):
        print "pclose: ", i, j, pclose[j]
        for p,q in enumerate(plevel):
            print "p,q",p, q, "plevel[j],j",plevel[j],j
            if plevel[j] == q:
                n[p] = n[p] * pclose[j]

    molform = ""
    for e,i in enumerate(elements):
        print elements[e], n[e]
        molform += "{e}:{n},".format(e=elements[e], n=n[e])
    molform = molform[:-1]
    print molform
    return molecule(molform, name=molecule_formula)


def is_number(s):
    try:
        float(s)
        return True
    except ValueError:
        return False
    

def get_element_by_name(element_name):
    for i in elements:
        #print i
        if elements[i].element.lower() == element_name.lower():
            return elements[i]
    return False #did not find in list

def get_element_by_symbol(symbol):
    for i in elements:
        #print i
        if elements[i].symbol.lower() == symbol.lower():
            return elements[i]
    return False #did not find in list


'''
   The rest of this file is created automatically using
    reorg.py
   which in turn uses that data in the text file
    atomic.txt
   which comes from Wikipedia.
''' 

elements = {}

H = element()
H.origin = "the Greek 'hydro' and 'genes' meaning water-forming"
H.melting = 14.01
H.group = 1
H.specific_heat_capacity = 14.304
H.weight = 1.0082
H.density = 0.00008988
H.symbol = "H"
H.period = 1
H.abundance = 1400
H.element = "Hydrogen"
H.boiling = 20.28
H.electronegativity = 2.20
H.n = 1
elements['H'] = H 

He = element()
He.origin = "the Greek 'helios' meaning sun"
He.melting = 0.956
He.group = 18
He.specific_heat_capacity = 5.193
He.weight = 4.002602
He.density = 0.0001785
He.symbol = "He"
He.period = 1
He.abundance = 0.008
He.element = "Helium"
He.boiling = 4.22
He.electronegativity = "–"
He.n = 2
elements['He'] = He 

Li = element()
Li.origin = "the Greek 'lithos' meaning stone"
Li.melting = 453.69
Li.group = 1
Li.specific_heat_capacity = 3.582
Li.weight = 6.942
Li.density = 0.534
Li.symbol = "Li"
Li.period = 2
Li.abundance = 20
Li.element = "Lithium"
Li.boiling = 1560
Li.electronegativity = 0.98
Li.n = 3
elements['Li'] = Li 

Be = element()
Be.origin = "the Greek name for beryl, 'beryllo'"
Be.melting = 1560
Be.group = 2
Be.specific_heat_capacity = 1.825
Be.weight = 9.012182
Be.density = 1.85
Be.symbol = "Be"
Be.period = 2
Be.abundance = 2.8
Be.element = "Beryllium"
Be.boiling = 2742
Be.electronegativity = 1.57
Be.n = 4
elements['Be'] = Be 

B = element()
B.origin = "the Arabic 'buraq', which was the name for borax"
B.melting = 2349
B.group = 13
B.specific_heat_capacity = 1.026
B.weight = 10.812
B.density = 2.34
B.symbol = "B"
B.period = 2
B.abundance = 10
B.element = "Boron"
B.boiling = 4200
B.electronegativity = 2.04
B.n = 5
elements['B'] = B 

C = element()
C.origin = "the Latin 'carbo', meaning charcoal"
C.melting = 3800
C.group = 14
C.specific_heat_capacity = 0.709
C.weight = 12.0112
C.density = 2.267
C.symbol = "C"
C.period = 2
C.abundance = 200
C.element = "Carbon"
C.boiling = 4300
C.electronegativity = 2.55
C.n = 6
elements['C'] = C 

N = element()
N.origin = "the Greek 'nitron' and 'genes' meaning nitre-forming"
N.melting = 63.15
N.group = 15
N.specific_heat_capacity = 1.04
N.weight = 14.0072
N.density = 0.0012506
N.symbol = "N"
N.period = 2
N.abundance = 19
N.element = "Nitrogen"
N.boiling = 77.36
N.electronegativity = 3.04
N.n = 7
elements['N'] = N 

O = element()
O.origin = "the Greek 'oxy' and 'genes' meaning acid-forming"
O.melting = 54.36
O.group = 16
O.specific_heat_capacity = 0.918
O.weight = 15.9992
O.density = 0.001429
O.symbol = "O"
O.period = 2
O.abundance = 461000
O.element = "Oxygen"
O.boiling = 90.20
O.electronegativity = 3.44
O.n = 8
elements['O'] = O 

F = element()
F.origin = "the Latin 'fluere', meaning to flow"
F.melting = 53.53
F.group = 17
F.specific_heat_capacity = 0.824
F.weight = 18.9984032
F.density = 0.001696
F.symbol = "F"
F.period = 2
F.abundance = 585
F.element = "Fluorine"
F.boiling = 85.03
F.electronegativity = 3.98
F.n = 9
elements['F'] = F 

Ne = element()
Ne.origin = "the Greek 'neos', meaning new"
Ne.melting = 24.56
Ne.group = 18
Ne.specific_heat_capacity = 1.03
Ne.weight = 20.1797
Ne.density = 0.0008999
Ne.symbol = "Ne"
Ne.period = 2
Ne.abundance = 0.005
Ne.element = "Neon"
Ne.boiling = 27.07
Ne.electronegativity = "–"
Ne.n = 10
elements['Ne'] = Ne 

Na = element()
Na.origin = "the English word soda (natrium in Latin)[2]"
Na.melting = 370.87
Na.group = 1
Na.specific_heat_capacity = 1.228
Na.weight = 22.98976928
Na.density = 0.971
Na.symbol = "Na"
Na.period = 3
Na.abundance = 23600
Na.element = "Sodium"
Na.boiling = 1156
Na.electronegativity = 0.93
Na.n = 11
elements['Na'] = Na 

Mg = element()
Mg.origin = "Magnesia, a district of Eastern Thessaly in Greece"
Mg.melting = 923
Mg.group = 2
Mg.specific_heat_capacity = 1.023
Mg.weight = 24.3059
Mg.density = 1.738
Mg.symbol = "Mg"
Mg.period = 3
Mg.abundance = 23300
Mg.element = "Magnesium"
Mg.boiling = 1363
Mg.electronegativity = 1.31
Mg.n = 12
elements['Mg'] = Mg 

Al = element()
Al.origin = "the Latin name for alum, 'alumen' meaning bitter salt"
Al.melting = "933.47[3]"
Al.group = 13
Al.specific_heat_capacity = 0.897
Al.weight = 26.9815386
Al.density = 2.698
Al.symbol = "Al"
Al.period = 3
Al.abundance = 82300
Al.element = "Aluminium"
Al.boiling = 2792
Al.electronegativity = 1.61
Al.n = 13
elements['Al'] = Al 

Si = element()
Si.origin = "the Latin 'silex' or 'silicis', meaning flint"
Si.melting = 1687
Si.group = 14
Si.specific_heat_capacity = 0.705
Si.weight = 28.0854
Si.density = 2.3296
Si.symbol = "Si"
Si.period = 3
Si.abundance = 282000
Si.element = "Silicon"
Si.boiling = 3538
Si.electronegativity = 1.9
Si.n = 14
elements['Si'] = Si 

P = element()
P.origin = "the Greek 'phosphoros', meaning bringer of light"
P.melting = 317.30
P.group = 15
P.specific_heat_capacity = 0.769
P.weight = 30.973762
P.density = 1.82
P.symbol = "P"
P.period = 3
P.abundance = 1050
P.element = "Phosphorus"
P.boiling = 550
P.electronegativity = 2.19
P.n = 15
elements['P'] = P 

S = element()
S.origin = "Either from the Sanskrit 'sulvere', or the Latin 'sulfurium', both names for sulfur[2]"
S.melting = 388.36
S.group = 16
S.specific_heat_capacity = 0.71
S.weight = 32.062
S.density = 2.067
S.symbol = "S"
S.period = 3
S.abundance = 350
S.element = "Sulfur"
S.boiling = 717.87
S.electronegativity = 2.58
S.n = 16
elements['S'] = S 

Cl = element()
Cl.origin = "the Greek 'chloros', meaning greenish yellow"
Cl.melting = 171.6
Cl.group = 17
Cl.specific_heat_capacity = 0.479
Cl.weight = 35.452
Cl.density = 0.003214
Cl.symbol = "Cl"
Cl.period = 3
Cl.abundance = 145
Cl.element = "Chlorine"
Cl.boiling = 239.11
Cl.electronegativity = 3.16
Cl.n = 17
elements['Cl'] = Cl 

Ar = element()
Ar.origin = "the Greek, 'argos', meaning idle"
Ar.melting = 83.80
Ar.group = 18
Ar.specific_heat_capacity = 0.52
Ar.weight = 39.948
Ar.density = 0.0017837
Ar.symbol = "Ar"
Ar.period = 3
Ar.abundance = 3.5
Ar.element = "Argon"
Ar.boiling = 87.30
Ar.electronegativity = "–"
Ar.n = 18
elements['Ar'] = Ar 

K = element()
K.origin = "the English word potash (kalium in Latin)[2]"
K.melting = 336.53
K.group = 1
K.specific_heat_capacity = 0.757
K.weight = 39.0983
K.density = 0.862
K.symbol = "K"
K.period = 4
K.abundance = 20900
K.element = "Potassium"
K.boiling = 1032
K.electronegativity = 0.82
K.n = 19
elements['K'] = K 

Ca = element()
Ca.origin = "the Latin 'calx' meaning lime"
Ca.melting = 1115
Ca.group = 2
Ca.specific_heat_capacity = 0.647
Ca.weight = 40.078
Ca.density = 1.54
Ca.symbol = "Ca"
Ca.period = 4
Ca.abundance = 41500
Ca.element = "Calcium"
Ca.boiling = 1757
Ca.electronegativity = 1
Ca.n = 20
elements['Ca'] = Ca 

Sc = element()
Sc.origin = "Scandinavia (with the Latin name Scandia)"
Sc.melting = 1814
Sc.group = 3
Sc.specific_heat_capacity = 0.568
Sc.weight = 44.955912
Sc.density = 2.989
Sc.symbol = "Sc"
Sc.period = 4
Sc.abundance = 22
Sc.element = "Scandium"
Sc.boiling = 3109
Sc.electronegativity = 1.36
Sc.n = 21
elements['Sc'] = Sc 

Ti = element()
Ti.origin = "Titans, the sons of the Earth goddess of Greek mythology"
Ti.melting = 1941
Ti.group = 4
Ti.specific_heat_capacity = 0.523
Ti.weight = 47.867
Ti.density = 4.54
Ti.symbol = "Ti"
Ti.period = 4
Ti.abundance = 5650
Ti.element = "Titanium"
Ti.boiling = 3560
Ti.electronegativity = 1.54
Ti.n = 22
elements['Ti'] = Ti 

V = element()
V.origin = "Vanadis, an old Norse name for the Scandinavian goddess Freyja"
V.melting = 2183
V.group = 5
V.specific_heat_capacity = 0.489
V.weight = 50.9415
V.density = 6.11
V.symbol = "V"
V.period = 4
V.abundance = 120
V.element = "Vanadium"
V.boiling = 3680
V.electronegativity = 1.63
V.n = 23
elements['V'] = V 

Cr = element()
Cr.origin = "the Greek 'chroma', meaning colour"
Cr.melting = 2180
Cr.group = 6
Cr.specific_heat_capacity = 0.449
Cr.weight = 51.9961
Cr.density = 7.15
Cr.symbol = "Cr"
Cr.period = 4
Cr.abundance = 102
Cr.element = "Chromium"
Cr.boiling = 2944
Cr.electronegativity = 1.66
Cr.n = 24
elements['Cr'] = Cr 

Mn = element()
Mn.origin = "Either the Latin 'magnes', meaning magnet or from the black magnesium oxide, 'magnesia nigra'"
Mn.melting = 1519
Mn.group = 7
Mn.specific_heat_capacity = 0.479
Mn.weight = 54.938045
Mn.density = 7.44
Mn.symbol = "Mn"
Mn.period = 4
Mn.abundance = 950
Mn.element = "Manganese"
Mn.boiling = 2334
Mn.electronegativity = 1.55
Mn.n = 25
elements['Mn'] = Mn 

Fe = element()
Fe.origin = "the Anglo-Saxon name iren (ferrum in Latin)"
Fe.melting = 1811
Fe.group = 8
Fe.specific_heat_capacity = 0.449
Fe.weight = 55.845
Fe.density = 7.874
Fe.symbol = "Fe"
Fe.period = 4
Fe.abundance = 56300
Fe.element = "Iron"
Fe.boiling = 3134
Fe.electronegativity = 1.83
Fe.n = 26
elements['Fe'] = Fe 

Co = element()
Co.origin = "the German word 'kobald', meaning goblin"
Co.melting = 1768
Co.group = 9
Co.specific_heat_capacity = 0.421
Co.weight = 58.933195
Co.density = 8.86
Co.symbol = "Co"
Co.period = 4
Co.abundance = 25
Co.element = "Cobalt"
Co.boiling = 3200
Co.electronegativity = 1.88
Co.n = 27
elements['Co'] = Co 

Ni = element()
Ni.origin = "the shortened of the German 'kupfernickel' meaning either devil's copper or St. Nicholas's copper"
Ni.melting = 1728
Ni.group = 10
Ni.specific_heat_capacity = 0.444
Ni.weight = 58.6934
Ni.density = 8.912
Ni.symbol = "Ni"
Ni.period = 4
Ni.abundance = 84
Ni.element = "Nickel"
Ni.boiling = 3186
Ni.electronegativity = 1.91
Ni.n = 28
elements['Ni'] = Ni 

Cu = element()
Cu.origin = "the Old English name coper in turn derived from the Latin 'Cyprium aes', meaning a metal from Cyprus"
Cu.melting = "1357.77[3]"
Cu.group = 11
Cu.specific_heat_capacity = 0.385
Cu.weight = 63.546
Cu.density = 8.96
Cu.symbol = "Cu"
Cu.period = 4
Cu.abundance = 60
Cu.element = "Copper"
Cu.boiling = 2835
Cu.electronegativity = 1.9
Cu.n = 29
elements['Cu'] = Cu 

Zn = element()
Zn.origin = "the German, 'zinc', which may in turn be derived from the Persian word 'sing', meaning stone"
Zn.melting = 692.88
Zn.group = 12
Zn.specific_heat_capacity = 0.388
Zn.weight = 65.38
Zn.density = 7.134
Zn.symbol = "Zn"
Zn.period = 4
Zn.abundance = 70
Zn.element = "Zinc"
Zn.boiling = 1180
Zn.electronegativity = 1.65
Zn.n = 30
elements['Zn'] = Zn 

Ga = element()
Ga.origin = "France (with the Latin name Gallia)"
Ga.melting = 302.9146
Ga.group = 13
Ga.specific_heat_capacity = 0.371
Ga.weight = 69.723
Ga.density = 5.907
Ga.symbol = "Ga"
Ga.period = 4
Ga.abundance = 19
Ga.element = "Gallium"
Ga.boiling = 2477
Ga.electronegativity = 1.81
Ga.n = 31
elements['Ga'] = Ga 

Ge = element()
Ge.origin = "Germany (with the Latin name Germania)"
Ge.melting = 1211.40
Ge.group = 14
Ge.specific_heat_capacity = 0.32
Ge.weight = 72.630
Ge.density = 5.323
Ge.symbol = "Ge"
Ge.period = 4
Ge.abundance = 1.5
Ge.element = "Germanium"
Ge.boiling = 3106
Ge.electronegativity = 2.01
Ge.n = 32
elements['Ge'] = Ge 

As = element()
As.origin = "the Greek name 'arsenikon' for the yellow pigment orpiment"
As.melting = "1090 7"
As.group = 15
As.specific_heat_capacity = 0.329
As.weight = 74.92160
As.density = 5.776
As.symbol = "As"
As.period = 4
As.abundance = 1.8
As.element = "Arsenic"
As.boiling = 887
As.electronegativity = 2.18
As.n = 33
elements['As'] = As 

Se = element()
Se.origin = "Moon (with the Greek name selene)"
Se.melting = 453
Se.group = 16
Se.specific_heat_capacity = 0.321
Se.weight = 78.96
Se.density = 4.809
Se.symbol = "Se"
Se.period = 4
Se.abundance = 0.05
Se.element = "Selenium"
Se.boiling = 958
Se.electronegativity = 2.55
Se.n = 34
elements['Se'] = Se 

Br = element()
Br.origin = "the Greek 'bromos' meaning stench"
Br.melting = 265.8
Br.group = 17
Br.specific_heat_capacity = 0.474
Br.weight = 79.9049
Br.density = 3.122
Br.symbol = "Br"
Br.period = 4
Br.abundance = 2.4
Br.element = "Bromine"
Br.boiling = 332.0
Br.electronegativity = 2.96
Br.n = 35
elements['Br'] = Br 

Kr = element()
Kr.origin = "the Greek 'kryptos', meaning hidden"
Kr.melting = 115.79
Kr.group = 18
Kr.specific_heat_capacity = 0.248
Kr.weight = 83.798
Kr.density = 0.003733
Kr.symbol = "Kr"
Kr.period = 4
Kr.abundance = "1×10−4"
Kr.element = "Krypton"
Kr.boiling = 119.93
Kr.electronegativity = 3
Kr.n = 36
elements['Kr'] = Kr 

Rb = element()
Rb.origin = "the Latin 'rubidius', meaning deepest red"
Rb.melting = 312.46
Rb.group = 1
Rb.specific_heat_capacity = 0.363
Rb.weight = 85.4678
Rb.density = 1.532
Rb.symbol = "Rb"
Rb.period = 5
Rb.abundance = 90
Rb.element = "Rubidium"
Rb.boiling = 961
Rb.electronegativity = 0.82
Rb.n = 37
elements['Rb'] = Rb 

Sr = element()
Sr.origin = "Strontian, a small town in Scotland"
Sr.melting = 1050
Sr.group = 2
Sr.specific_heat_capacity = 0.301
Sr.weight = 87.62
Sr.density = 2.64
Sr.symbol = "Sr"
Sr.period = 5
Sr.abundance = 370
Sr.element = "Strontium"
Sr.boiling = 1655
Sr.electronegativity = 0.95
Sr.n = 38
elements['Sr'] = Sr 

Y = element()
Y.origin = "Ytterby, Sweden"
Y.melting = 1799
Y.group = 3
Y.specific_heat_capacity = 0.298
Y.weight = 88.90585
Y.density = 4.469
Y.symbol = "Y"
Y.period = 5
Y.abundance = 33
Y.element = "Yttrium"
Y.boiling = 3609
Y.electronegativity = 1.22
Y.n = 39
elements['Y'] = Y 

Zr = element()
Zr.origin = "the Persian 'zargun', meaning gold coloured"
Zr.melting = 2128
Zr.group = 4
Zr.specific_heat_capacity = 0.278
Zr.weight = 91.224
Zr.density = 6.506
Zr.symbol = "Zr"
Zr.period = 5
Zr.abundance = 165
Zr.element = "Zirconium"
Zr.boiling = 4682
Zr.electronegativity = 1.33
Zr.n = 40
elements['Zr'] = Zr 

Nb = element()
Nb.origin = "Niobe, daughter of king Tantalus from Greek mythology"
Nb.melting = 2750
Nb.group = 5
Nb.specific_heat_capacity = 0.265
Nb.weight = 92.90638
Nb.density = 8.57
Nb.symbol = "Nb"
Nb.period = 5
Nb.abundance = 20
Nb.element = "Niobium"
Nb.boiling = 5017
Nb.electronegativity = 1.6
Nb.n = 41
elements['Nb'] = Nb 

Mo = element()
Mo.origin = "the Greek 'molybdos' meaning lead"
Mo.melting = 2896
Mo.group = 6
Mo.specific_heat_capacity = 0.251
Mo.weight = 95.96
Mo.density = 10.22
Mo.symbol = "Mo"
Mo.period = 5
Mo.abundance = 1.2
Mo.element = "Molybdenum"
Mo.boiling = 4912
Mo.electronegativity = 2.16
Mo.n = 42
elements['Mo'] = Mo 

Tc = element()
Tc.origin = "the Greek 'tekhnetos' meaning artificial"
Tc.melting = 2430
Tc.group = 7
Tc.specific_heat_capacity = "–"
Tc.weight = "[98]1"
Tc.density = 11.5
Tc.symbol = "Tc"
Tc.period = 5
Tc.abundance = "~ 3×10−9"
Tc.element = "Technetium"
Tc.boiling = 4538
Tc.electronegativity = 1.9
Tc.n = 43
elements['Tc'] = Tc 

Ru = element()
Ru.origin = "Russia (with the Latin name Ruthenia)"
Ru.melting = 2607
Ru.group = 8
Ru.specific_heat_capacity = 0.238
Ru.weight = 101.07
Ru.density = 12.37
Ru.symbol = "Ru"
Ru.period = 5
Ru.abundance = 0.001
Ru.element = "Ruthenium"
Ru.boiling = 4423
Ru.electronegativity = 2.2
Ru.n = 44
elements['Ru'] = Ru 

Rh = element()
Rh.origin = "the Greek 'rhodon', meaning rose coloured"
Rh.melting = 2237
Rh.group = 9
Rh.specific_heat_capacity = 0.243
Rh.weight = 102.90550
Rh.density = 12.41
Rh.symbol = "Rh"
Rh.period = 5
Rh.abundance = 0.001
Rh.element = "Rhodium"
Rh.boiling = 3968
Rh.electronegativity = 2.28
Rh.n = 45
elements['Rh'] = Rh 

Pd = element()
Pd.origin = "the then recently discovered asteroid Pallas, considered a planet at the time"
Pd.melting = 1828.05
Pd.group = 10
Pd.specific_heat_capacity = 0.244
Pd.weight = 106.42
Pd.density = 12.02
Pd.symbol = "Pd"
Pd.period = 5
Pd.abundance = 0.015
Pd.element = "Palladium"
Pd.boiling = 3236
Pd.electronegativity = 2.2
Pd.n = 46
elements['Pd'] = Pd 

Ag = element()
Ag.origin = "the Anglo-Saxon name siolfur (argentum in Latin)[2]"
Ag.melting = "1234.93[3]"
Ag.group = 11
Ag.specific_heat_capacity = 0.235
Ag.weight = 107.8682
Ag.density = 10.501
Ag.symbol = "Ag"
Ag.period = 5
Ag.abundance = 0.075
Ag.element = "Silver"
Ag.boiling = 2435
Ag.electronegativity = 1.93
Ag.n = 47
elements['Ag'] = Ag 

Cd = element()
Cd.origin = "the Latin name for the mineral calmine, 'cadmia'"
Cd.melting = 594.22
Cd.group = 12
Cd.specific_heat_capacity = 0.232
Cd.weight = 112.411
Cd.density = 8.69
Cd.symbol = "Cd"
Cd.period = 5
Cd.abundance = 0.159
Cd.element = "Cadmium"
Cd.boiling = 1040
Cd.electronegativity = 1.69
Cd.n = 48
elements['Cd'] = Cd 

In = element()
In.origin = "the Latin 'indicium', meaning violet or indigo"
In.melting = 429.75
In.group = 13
In.specific_heat_capacity = 0.233
In.weight = 114.818
In.density = 7.31
In.symbol = "In"
In.period = 5
In.abundance = 0.25
In.element = "Indium"
In.boiling = 2345
In.electronegativity = 1.78
In.n = 49
elements['In'] = In 

Sn = element()
Sn.origin = "the Anglo-Saxon word tin (stannum in Latin, meaning hard)"
Sn.melting = 505.08
Sn.group = 14
Sn.specific_heat_capacity = 0.228
Sn.weight = 118.710
Sn.density = 7.287
Sn.symbol = "Sn"
Sn.period = 5
Sn.abundance = 2.3
Sn.element = "Tin"
Sn.boiling = 2875
Sn.electronegativity = 1.96
Sn.n = 50
elements['Sn'] = Sn 

Sb = element()
Sb.origin = "the Greek 'anti – monos', meaning not alone (stibium in Latin)"
Sb.melting = 903.78
Sb.group = 15
Sb.specific_heat_capacity = 0.207
Sb.weight = 121.760
Sb.density = 6.685
Sb.symbol = "Sb"
Sb.period = 5
Sb.abundance = 0.2
Sb.element = "Antimony"
Sb.boiling = 1860
Sb.electronegativity = 2.05
Sb.n = 51
elements['Sb'] = Sb 

Te = element()
Te.origin = "Earth, the third planet in the solar system (with the Latin word tellus)"
Te.melting = 722.66
Te.group = 16
Te.specific_heat_capacity = 0.202
Te.weight = 127.60
Te.density = 6.232
Te.symbol = "Te"
Te.period = 5
Te.abundance = 0.001
Te.element = "Tellurium"
Te.boiling = 1261
Te.electronegativity = 2.1
Te.n = 52
elements['Te'] = Te 

I = element()
I.origin = "the Greek 'iodes' meaning violet"
I.melting = 386.85
I.group = 17
I.specific_heat_capacity = 0.214
I.weight = 126.90447
I.density = 4.93
I.symbol = "I"
I.period = 5
I.abundance = 0.45
I.element = "Iodine"
I.boiling = 457.4
I.electronegativity = 2.66
I.n = 53
elements['I'] = I 

Xe = element()
Xe.origin = "the Greek 'xenos' meaning stranger"
Xe.melting = 161.4
Xe.group = 18
Xe.specific_heat_capacity = 0.158
Xe.weight = 131.293
Xe.density = 0.005887
Xe.symbol = "Xe"
Xe.period = 5
Xe.abundance = "3×10−5"
Xe.element = "Xenon"
Xe.boiling = 165.03
Xe.electronegativity = 2.6
Xe.n = 54
elements['Xe'] = Xe 

Cs = element()
Cs.origin = "the Latin 'caesius', meaning sky blue"
Cs.melting = 301.59
Cs.group = 1
Cs.specific_heat_capacity = 0.242
Cs.weight = 132.9054519
Cs.density = 1.873
Cs.symbol = "Cs"
Cs.period = 6
Cs.abundance = 3
Cs.element = "Caesium"
Cs.boiling = 944
Cs.electronegativity = 0.79
Cs.n = 55
elements['Cs'] = Cs 

Ba = element()
Ba.origin = "the Greek 'barys', meaning heavy"
Ba.melting = 1000
Ba.group = 2
Ba.specific_heat_capacity = 0.204
Ba.weight = 137.327
Ba.density = 3.594
Ba.symbol = "Ba"
Ba.period = 6
Ba.abundance = 425
Ba.element = "Barium"
Ba.boiling = 2170
Ba.electronegativity = 0.89
Ba.n = 56
elements['Ba'] = Ba 

La = element()
La.origin = "the Greek 'lanthanein', meaning to lie hidden"
La.melting = 1193
La.group = ""
La.specific_heat_capacity = 0.195
La.weight = 138.90547
La.density = 6.145
La.symbol = "La"
La.period = 6
La.abundance = 39
La.element = "Lanthanum"
La.boiling = 3737
La.electronegativity = 1.1
La.n = 57
elements['La'] = La 

Ce = element()
Ce.origin = "the then recently discovered asteroid Ceres, considered a planet at the time"
Ce.melting = 1068
Ce.group = ""
Ce.specific_heat_capacity = 0.192
Ce.weight = 140.116
Ce.density = 6.77
Ce.symbol = "Ce"
Ce.period = 6
Ce.abundance = 66.5
Ce.element = "Cerium"
Ce.boiling = 3716
Ce.electronegativity = 1.12
Ce.n = 58
elements['Ce'] = Ce 

Pr = element()
Pr.origin = "the Greek 'prasinos didymos' meaning green twin"
Pr.melting = 1208
Pr.group = ""
Pr.specific_heat_capacity = 0.193
Pr.weight = 140.90765
Pr.density = 6.773
Pr.symbol = "Pr"
Pr.period = 6
Pr.abundance = 9.2
Pr.element = "Praseodymium"
Pr.boiling = 3793
Pr.electronegativity = 1.13
Pr.n = 59
elements['Pr'] = Pr 

Nd = element()
Nd.origin = "the Greek 'neos didymos' meaning new twin"
Nd.melting = 1297
Nd.group = ""
Nd.specific_heat_capacity = 0.19
Nd.weight = 144.242
Nd.density = 7.007
Nd.symbol = "Nd"
Nd.period = 6
Nd.abundance = 41.5
Nd.element = "Neodymium"
Nd.boiling = 3347
Nd.electronegativity = 1.14
Nd.n = 60
elements['Nd'] = Nd 

Pm = element()
Pm.origin = "Prometheus of Greek mythology who stole fire from the Gods and gave it to humans"
Pm.melting = 1315
Pm.group = ""
Pm.specific_heat_capacity = "–"
Pm.weight = "[145]1"
Pm.density = 7.26
Pm.symbol = "Pm"
Pm.period = 6
Pm.abundance = "2×10−19"
Pm.element = "Promethium"
Pm.boiling = 3273
Pm.electronegativity = 1.13
Pm.n = 61
elements['Pm'] = Pm 

Sm = element()
Sm.origin = "Samarskite, the name of the mineral from which it was first isolated"
Sm.melting = 1345
Sm.group = ""
Sm.specific_heat_capacity = 0.197
Sm.weight = 150.36
Sm.density = 7.52
Sm.symbol = "Sm"
Sm.period = 6
Sm.abundance = 7.05
Sm.element = "Samarium"
Sm.boiling = 2067
Sm.electronegativity = 1.17
Sm.n = 62
elements['Sm'] = Sm 

Eu = element()
Eu.origin = "Europe"
Eu.melting = 1099
Eu.group = ""
Eu.specific_heat_capacity = 0.182
Eu.weight = 151.964
Eu.density = 5.243
Eu.symbol = "Eu"
Eu.period = 6
Eu.abundance = 2
Eu.element = "Europium"
Eu.boiling = 1802
Eu.electronegativity = 1.2
Eu.n = 63
elements['Eu'] = Eu 

Gd = element()
Gd.origin = "Johan Gadolin, chemist, physicist and mineralogist"
Gd.melting = 1585
Gd.group = ""
Gd.specific_heat_capacity = 0.236
Gd.weight = 157.25
Gd.density = 7.895
Gd.symbol = "Gd"
Gd.period = 6
Gd.abundance = 6.2
Gd.element = "Gadolinium"
Gd.boiling = 3546
Gd.electronegativity = 1.2
Gd.n = 64
elements['Gd'] = Gd 

Tb = element()
Tb.origin = "Ytterby, Sweden"
Tb.melting = 1629
Tb.group = ""
Tb.specific_heat_capacity = 0.182
Tb.weight = 158.92535
Tb.density = 8.229
Tb.symbol = "Tb"
Tb.period = 6
Tb.abundance = 1.2
Tb.element = "Terbium"
Tb.boiling = 3503
Tb.electronegativity = 1.2
Tb.n = 65
elements['Tb'] = Tb 

Dy = element()
Dy.origin = "the Greek 'dysprositos', meaning hard to get"
Dy.melting = 1680
Dy.group = ""
Dy.specific_heat_capacity = 0.17
Dy.weight = 162.500
Dy.density = 8.55
Dy.symbol = "Dy"
Dy.period = 6
Dy.abundance = 5.2
Dy.element = "Dysprosium"
Dy.boiling = 2840
Dy.electronegativity = 1.22
Dy.n = 66
elements['Dy'] = Dy 

Ho = element()
Ho.origin = "Stockholm, Sweden (with the Latin name Holmia)"
Ho.melting = 1734
Ho.group = ""
Ho.specific_heat_capacity = 0.165
Ho.weight = 164.93032
Ho.density = 8.795
Ho.symbol = "Ho"
Ho.period = 6
Ho.abundance = 1.3
Ho.element = "Holmium"
Ho.boiling = 2993
Ho.electronegativity = 1.23
Ho.n = 67
elements['Ho'] = Ho 

Er = element()
Er.origin = "Ytterby, Sweden"
Er.melting = 1802
Er.group = ""
Er.specific_heat_capacity = 0.168
Er.weight = 167.259
Er.density = 9.066
Er.symbol = "Er"
Er.period = 6
Er.abundance = 3.5
Er.element = "Erbium"
Er.boiling = 3141
Er.electronegativity = 1.24
Er.n = 68
elements['Er'] = Er 

Tm = element()
Tm.origin = "Thule, the ancient name for Scandinavia"
Tm.melting = 1818
Tm.group = ""
Tm.specific_heat_capacity = 0.16
Tm.weight = 168.93421
Tm.density = 9.321
Tm.symbol = "Tm"
Tm.period = 6
Tm.abundance = 0.52
Tm.element = "Thulium"
Tm.boiling = 2223
Tm.electronegativity = 1.25
Tm.n = 69
elements['Tm'] = Tm 

Yb = element()
Yb.origin = "Ytterby, Sweden"
Yb.melting = 1097
Yb.group = ""
Yb.specific_heat_capacity = 0.155
Yb.weight = 173.054
Yb.density = 6.965
Yb.symbol = "Yb"
Yb.period = 6
Yb.abundance = 3.2
Yb.element = "Ytterbium"
Yb.boiling = 1469
Yb.electronegativity = 1.1
Yb.n = 70
elements['Yb'] = Yb 

Lu = element()
Lu.origin = "Paris, France (with the Roman name Lutetia)"
Lu.melting = 1925
Lu.group = 3
Lu.specific_heat_capacity = 0.154
Lu.weight = 174.9668
Lu.density = 9.84
Lu.symbol = "Lu"
Lu.period = 6
Lu.abundance = 0.8
Lu.element = "Lutetium"
Lu.boiling = 3675
Lu.electronegativity = 1.27
Lu.n = 71
elements['Lu'] = Lu 

Hf = element()
Hf.origin = "Copenhagen, Denmark (with the Latin name Hafnia)"
Hf.melting = 2506
Hf.group = 4
Hf.specific_heat_capacity = 0.144
Hf.weight = 178.49
Hf.density = 13.31
Hf.symbol = "Hf"
Hf.period = 6
Hf.abundance = 3
Hf.element = "Hafnium"
Hf.boiling = 4876
Hf.electronegativity = 1.3
Hf.n = 72
elements['Hf'] = Hf 

Ta = element()
Ta.origin = "King Tantalus, father of Niobe from Greek mythology"
Ta.melting = 3290
Ta.group = 5
Ta.specific_heat_capacity = 0.14
Ta.weight = 180.94788
Ta.density = 16.654
Ta.symbol = "Ta"
Ta.period = 6
Ta.abundance = 2
Ta.element = "Tantalum"
Ta.boiling = 5731
Ta.electronegativity = 1.5
Ta.n = 73
elements['Ta'] = Ta 

W = element()
W.origin = "the Swedish 'tung sten' meaning heavy stone (W is wolfram, the old name of the tungsten mineral wolframite)[2]"
W.melting = 3695
W.group = 6
W.specific_heat_capacity = 0.132
W.weight = 183.84
W.density = 19.25
W.symbol = "W"
W.period = 6
W.abundance = 1.3
W.element = "Tungsten"
W.boiling = 5828
W.electronegativity = 2.36
W.n = 74
elements['W'] = W 

Re = element()
Re.origin = "Rhine, a river that flows from Grisons in the eastern Swiss Alps to the North Sea coast in the Netherlands (with the Latin name Rhenia)"
Re.melting = 3459
Re.group = 7
Re.specific_heat_capacity = 0.137
Re.weight = 186.207
Re.density = 21.02
Re.symbol = "Re"
Re.period = 6
Re.abundance = "7×10−4"
Re.element = "Rhenium"
Re.boiling = 5869
Re.electronegativity = 1.9
Re.n = 75
elements['Re'] = Re 

Os = element()
Os.origin = "the Greek 'osme', meaning smell"
Os.melting = 3306
Os.group = 8
Os.specific_heat_capacity = 0.13
Os.weight = 190.23
Os.density = 22.61
Os.symbol = "Os"
Os.period = 6
Os.abundance = 0.002
Os.element = "Osmium"
Os.boiling = 5285
Os.electronegativity = 2.2
Os.n = 76
elements['Os'] = Os 

Ir = element()
Ir.origin = "Iris, the Greek goddess of the rainbow"
Ir.melting = 2719
Ir.group = 9
Ir.specific_heat_capacity = 0.131
Ir.weight = 192.217
Ir.density = 22.56
Ir.symbol = "Ir"
Ir.period = 6
Ir.abundance = 0.001
Ir.element = "Iridium"
Ir.boiling = 4701
Ir.electronegativity = 2.2
Ir.n = 77
elements['Ir'] = Ir 

Pt = element()
Pt.origin = "the Spanish 'platina', meaning little silver"
Pt.melting = "2041.4[3]"
Pt.group = 10
Pt.specific_heat_capacity = 0.133
Pt.weight = 195.084
Pt.density = 21.46
Pt.symbol = "Pt"
Pt.period = 6
Pt.abundance = 0.005
Pt.element = "Platinum"
Pt.boiling = 4098
Pt.electronegativity = 2.28
Pt.n = 78
elements['Pt'] = Pt 

Au = element()
Au.origin = "the Anglo-Saxon word gold (aurum in Latin, meaning glow of sunrise)[2]"
Au.melting = "1337.33[3]"
Au.group = 11
Au.specific_heat_capacity = 0.129
Au.weight = 196.966569
Au.density = 19.282
Au.symbol = "Au"
Au.period = 6
Au.abundance = 0.004
Au.element = "Gold"
Au.boiling = 3129
Au.electronegativity = 2.54
Au.n = 79
elements['Au'] = Au 

Hg = element()
Hg.origin = "Mercury, the first planet in the Solar System (Hg from former name hydrargyrum, from Greek hydr- water and argyros silver)"
Hg.melting = 234.43
Hg.group = 12
Hg.specific_heat_capacity = 0.14
Hg.weight = 200.592
Hg.density = 13.5336
Hg.symbol = "Hg"
Hg.period = 6
Hg.abundance = 0.085
Hg.element = "Mercury"
Hg.boiling = 629.88
Hg.electronegativity = 2
Hg.n = 80
elements['Hg'] = Hg 

Tl = element()
Tl.origin = "the Greek 'thallos', meaning a green twig"
Tl.melting = 577
Tl.group = 13
Tl.specific_heat_capacity = 0.129
Tl.weight = 204.389
Tl.density = 11.85
Tl.symbol = "Tl"
Tl.period = 6
Tl.abundance = 0.85
Tl.element = "Thallium"
Tl.boiling = 1746
Tl.electronegativity = 1.62
Tl.n = 81
elements['Tl'] = Tl 

Pb = element()
Pb.origin = "the Anglo-Saxon lead (plumbum in Latin)[2]"
Pb.melting = 600.61
Pb.group = 14
Pb.specific_heat_capacity = 0.129
Pb.weight = 207.2
Pb.density = 11.342
Pb.symbol = "Pb"
Pb.period = 6
Pb.abundance = 14
Pb.element = "Lead"
Pb.boiling = 2022
Pb.electronegativity = 1.87
Pb.n = 82
elements['Pb'] = Pb 

Bi = element()
Bi.origin = "the German 'Bisemutum' a corruption of 'Weisse Masse' meaning white mass"
Bi.melting = 544.7
Bi.group = 15
Bi.specific_heat_capacity = 0.122
Bi.weight = 208.98040
Bi.density = 9.807
Bi.symbol = "Bi"
Bi.period = 6
Bi.abundance = 0.009
Bi.element = "Bismuth"
Bi.boiling = 1837
Bi.electronegativity = 2.02
Bi.n = 83
elements['Bi'] = Bi 

Po = element()
Po.origin = "Poland, the native country of Marie Curie, who first isolated the element"
Po.melting = 527
Po.group = 16
Po.specific_heat_capacity = "–"
Po.weight = "[209]1"
Po.density = 9.32
Po.symbol = "Po"
Po.period = 6
Po.abundance = "2×10−10"
Po.element = "Polonium"
Po.boiling = 1235
Po.electronegativity = 2.0
Po.n = 84
elements['Po'] = Po 

At = element()
At.origin = "the Greek 'astatos', meaning unstable"
At.melting = 575
At.group = 17
At.specific_heat_capacity = "–"
At.weight = "[210]1"
At.density = 7
At.symbol = "At"
At.period = 6
At.abundance = "3×10−20"
At.element = "Astatine"
At.boiling = 610
At.electronegativity = 2.2
At.n = 85
elements['At'] = At 

Rn = element()
Rn.origin = "From radium, as it was first detected as an emission from radium during radioactive decay"
Rn.melting = 202
Rn.group = 18
Rn.specific_heat_capacity = 0.094
Rn.weight = "[222]1"
Rn.density = 0.00973
Rn.symbol = "Rn"
Rn.period = 6
Rn.abundance = "4×10−13"
Rn.element = "Radon"
Rn.boiling = 211.3
Rn.electronegativity = 2.2
Rn.n = 86
elements['Rn'] = Rn 

Fr = element()
Fr.origin = "France, where it was first discovered"
Fr.melting = 300
Fr.group = 1
Fr.specific_heat_capacity = "–"
Fr.weight = "[223]1"
Fr.density = 1.87
Fr.symbol = "Fr"
Fr.period = 7
Fr.abundance = "~ 1×10−18"
Fr.element = "Francium"
Fr.boiling = 950
Fr.electronegativity = 0.7
Fr.n = 87
elements['Fr'] = Fr 

Ra = element()
Ra.origin = "the Latin 'radius', meaning ray"
Ra.melting = 973
Ra.group = 2
Ra.specific_heat_capacity = 0.094
Ra.weight = "[226]1"
Ra.density = 5.5
Ra.symbol = "Ra"
Ra.period = 7
Ra.abundance = "9×10−9"
Ra.element = "Radium"
Ra.boiling = 2010
Ra.electronegativity = 0.9
Ra.n = 88
elements['Ra'] = Ra 

Ac = element()
Ac.origin = "the Greek 'actinos', meaning a ray"
Ac.melting = 1323
Ac.group = ""
Ac.specific_heat_capacity = 0.12
Ac.weight = "[227]1"
Ac.density = 10.07
Ac.symbol = "Ac"
Ac.period = 7
Ac.abundance = "5.5×10−10"
Ac.element = "Actinium"
Ac.boiling = 3471
Ac.electronegativity = 1.1
Ac.n = 89
elements['Ac'] = Ac 

Th = element()
Th.origin = "Thor, the Scandinavian god of thunder"
Th.melting = 2115
Th.group = ""
Th.specific_heat_capacity = 0.113
Th.weight = 232.03806
Th.density = 11.72
Th.symbol = "Th"
Th.period = 7
Th.abundance = 9.6
Th.element = "Thorium"
Th.boiling = 5061
Th.electronegativity = 1.3
Th.n = 90
elements['Th'] = Th 

Pa = element()
Pa.origin = "the Greek 'protos', meaning first, as a prefix to the element actinium, which is produced through the radioactive decay of protactinium"
Pa.melting = 1841
Pa.group = ""
Pa.specific_heat_capacity = "–"
Pa.weight = 231.03588
Pa.density = 15.37
Pa.symbol = "Pa"
Pa.period = 7
Pa.abundance = "1.4×10−6"
Pa.element = "Protactinium"
Pa.boiling = 4300
Pa.electronegativity = 1.5
Pa.n = 91
elements['Pa'] = Pa 

U = element()
U.origin = "Uranus, the seventh planet in the Solar System"
U.melting = 1405.3
U.group = ""
U.specific_heat_capacity = 0.116
U.weight = 238.02891
U.density = 18.95
U.symbol = "U"
U.period = 7
U.abundance = 2.7
U.element = "Uranium"
U.boiling = 4404
U.electronegativity = 1.38
U.n = 92
elements['U'] = U 

Np = element()
Np.origin = "Neptune, the eighth planet in the Solar System"
Np.melting = 917
Np.group = ""
Np.specific_heat_capacity = "–"
Np.weight = "[237]1"
Np.density = 20.45
Np.symbol = "Np"
Np.period = 7
Np.abundance = "≤ 3×10−12"
Np.element = "Neptunium"
Np.boiling = 4273
Np.electronegativity = 1.36
Np.n = 93
elements['Np'] = Np 

Pu = element()
Pu.origin = "Pluto, a dwarf planet in the Solar System"
Pu.melting = 912.5
Pu.group = ""
Pu.specific_heat_capacity = "–"
Pu.weight = "[244]1"
Pu.density = 19.84
Pu.symbol = "Pu"
Pu.period = 7
Pu.abundance = "≤ 3×10−11"
Pu.element = "Plutonium"
Pu.boiling = 3501
Pu.electronegativity = 1.28
Pu.n = 94
elements['Pu'] = Pu 

Am = element()
Am.origin = "Americas, the continent where the element was first synthesized"
Am.melting = 1449
Am.group = ""
Am.specific_heat_capacity = "–"
Am.weight = "[243]1"
Am.density = 13.69
Am.symbol = "Am"
Am.period = 7
Am.abundance = "~ 3×10−33"
Am.element = "Americium"
Am.boiling = 2880
Am.electronegativity = 1.13
Am.n = 95
elements['Am'] = Am 

Cm = element()
Cm.origin = "Pierre Curie, a physicist, and Marie Curie, a physicist and chemist"
Cm.melting = 1613
Cm.group = ""
Cm.specific_heat_capacity = "–"
Cm.weight = "[247]1"
Cm.density = 13.51
Cm.symbol = "Cm"
Cm.period = 7
Cm.abundance = "~ 2×10−32"
Cm.element = "Curium"
Cm.boiling = 3383
Cm.electronegativity = 1.28
Cm.n = 96
elements['Cm'] = Cm 

Bk = element()
Bk.origin = "Berkeley, California, USA, where the element was first synthesized"
Bk.melting = 1259
Bk.group = ""
Bk.specific_heat_capacity = "–"
Bk.weight = "[247]1"
Bk.density = 14.79
Bk.symbol = "Bk"
Bk.period = 7
Bk.abundance = "~ 0"
Bk.element = "Berkelium"
Bk.boiling = 2900
Bk.electronegativity = 1.3
Bk.n = 97
elements['Bk'] = Bk 

Cf = element()
Cf.origin = "State of California, USA, where the element was first synthesized"
Cf.melting = 1173
Cf.group = ""
Cf.specific_heat_capacity = "–"
Cf.weight = "[251]1"
Cf.density = 15.1
Cf.symbol = "Cf"
Cf.period = 7
Cf.abundance = "~ 0"
Cf.element = "Californium"
Cf.boiling = "(1743)11"
Cf.electronegativity = 1.3
Cf.n = 98
elements['Cf'] = Cf 

Es = element()
Es.origin = "Albert Einstein, physicist"
Es.melting = 1133
Es.group = ""
Es.specific_heat_capacity = "–"
Es.weight = "[252]1"
Es.density = 8.84
Es.symbol = "Es"
Es.period = 7
Es.abundance = "0 8"
Es.element = "Einsteinium"
Es.boiling = "(1269)11"
Es.electronegativity = 1.3
Es.n = 99
elements['Es'] = Es 

Fm = element()
Fm.origin = "Enrico Fermi, physicist"
Fm.melting = "(1125)11"
Fm.group = ""
Fm.specific_heat_capacity = "–"
Fm.weight = "[257]1"
Fm.density = "–"
Fm.symbol = "Fm"
Fm.period = 7
Fm.abundance = "0 8"
Fm.element = "Fermium"
Fm.boiling = "–"
Fm.electronegativity = 1.3
Fm.n = 100
elements['Fm'] = Fm 

Md = element()
Md.origin = "Dmitri Mendeleyev, chemist and inventor"
Md.melting = "(1100)11"
Md.group = ""
Md.specific_heat_capacity = "–"
Md.weight = "[258]1"
Md.density = "–"
Md.symbol = "Md"
Md.period = 7
Md.abundance = "0 8"
Md.element = "Mendelevium"
Md.boiling = "–"
Md.electronegativity = 1.3
Md.n = 101
elements['Md'] = Md 

No = element()
No.origin = "Alfred Nobel, chemist, engineer, innovator, and armaments manufacturer"
No.melting = "(1100)11"
No.group = ""
No.specific_heat_capacity = "–"
No.weight = "[259]1"
No.density = "–"
No.symbol = "No"
No.period = 7
No.abundance = "0 8"
No.element = "Nobelium"
No.boiling = "–"
No.electronegativity = 1.3
No.n = 102
elements['No'] = No 

Lr = element()
Lr.origin = "Ernest O. Lawrence, physicist"
Lr.melting = "(1900)11"
Lr.group = 3
Lr.specific_heat_capacity = "–"
Lr.weight = "[266]1"
Lr.density = "–"
Lr.symbol = "Lr"
Lr.period = 7
Lr.abundance = "0 8"
Lr.element = "Lawrencium"
Lr.boiling = "–"
Lr.electronegativity = 1.3
Lr.n = 103
elements['Lr'] = Lr 

Rf = element()
Rf.origin = "Ernest Rutherford, chemist and physicist"
Rf.melting = "(2400)11"
Rf.group = 4
Rf.specific_heat_capacity = "–"
Rf.weight = "[267]1"
Rf.density = "(23.2)11"
Rf.symbol = "Rf"
Rf.period = 7
Rf.abundance = "0 8"
Rf.element = "Rutherfordium"
Rf.boiling = "(5800)11"
Rf.electronegativity = "–"
Rf.n = 104
elements['Rf'] = Rf 

Db = element()
Db.origin = "Dubna, Russia"
Db.melting = "–"
Db.group = 5
Db.specific_heat_capacity = "–"
Db.weight = "[268]1"
Db.density = "(29.3)11"
Db.symbol = "Db"
Db.period = 7
Db.abundance = "0 8"
Db.element = "Dubnium"
Db.boiling = "–"
Db.electronegativity = "–"
Db.n = 105
elements['Db'] = Db 

Sg = element()
Sg.origin = "Glenn T. Seaborg, scientist"
Sg.melting = "–"
Sg.group = 6
Sg.specific_heat_capacity = "–"
Sg.weight = "[269]1"
Sg.density = "(35.0)11"
Sg.symbol = "Sg"
Sg.period = 7
Sg.abundance = "0 8"
Sg.element = "Seaborgium"
Sg.boiling = "–"
Sg.electronegativity = "–"
Sg.n = 106
elements['Sg'] = Sg 

Bh = element()
Bh.origin = "Niels Bohr, physicist"
Bh.melting = "–"
Bh.group = 7
Bh.specific_heat_capacity = "–"
Bh.weight = "[270]1"
Bh.density = "(37.1)11"
Bh.symbol = "Bh"
Bh.period = 7
Bh.abundance = "0 8"
Bh.element = "Bohrium"
Bh.boiling = "–"
Bh.electronegativity = "–"
Bh.n = 107
elements['Bh'] = Bh 

Hs = element()
Hs.origin = "Hesse, Germany, where the element was first synthesized"
Hs.melting = "–"
Hs.group = 8
Hs.specific_heat_capacity = "–"
Hs.weight = "[269]1"
Hs.density = "(40.7)11"
Hs.symbol = "Hs"
Hs.period = 7
Hs.abundance = "0 8"
Hs.element = "Hassium"
Hs.boiling = "–"
Hs.electronegativity = "–"
Hs.n = 108
elements['Hs'] = Hs 

Mt = element()
Mt.origin = "Lise Meitner, physicist"
Mt.melting = "–"
Mt.group = 9
Mt.specific_heat_capacity = "–"
Mt.weight = "[278]1"
Mt.density = "(37.4)11"
Mt.symbol = "Mt"
Mt.period = 7
Mt.abundance = "0 8"
Mt.element = "Meitnerium"
Mt.boiling = "–"
Mt.electronegativity = "–"
Mt.n = 109
elements['Mt'] = Mt 

Ds = element()
Ds.origin = "Darmstadt, Germany, where the element was first synthesized"
Ds.melting = "–"
Ds.group = 10
Ds.specific_heat_capacity = "–"
Ds.weight = "[281]1"
Ds.density = "(34.8)11"
Ds.symbol = "Ds"
Ds.period = 7
Ds.abundance = "0 8"
Ds.element = "Darmstadtium"
Ds.boiling = "–"
Ds.electronegativity = "–"
Ds.n = 110
elements['Ds'] = Ds 

Rg = element()
Rg.origin = "Wilhelm Conrad Röntgen, physicist"
Rg.melting = "–"
Rg.group = 11
Rg.specific_heat_capacity = "–"
Rg.weight = "[281]1"
Rg.density = "(28.7)11"
Rg.symbol = "Rg"
Rg.period = 7
Rg.abundance = "0 8"
Rg.element = "Roentgenium"
Rg.boiling = "–"
Rg.electronegativity = "–"
Rg.n = 111
elements['Rg'] = Rg 

Cn = element()
Cn.origin = "Nicolaus Copernicus, astronomer"
Cn.melting = "–"
Cn.group = 12
Cn.specific_heat_capacity = "–"
Cn.weight = "[285]1"
Cn.density = "(23.7)11"
Cn.symbol = "Cn"
Cn.period = 7
Cn.abundance = "0 8"
Cn.element = "Copernicium"
Cn.boiling = "357 12"
Cn.electronegativity = "–"
Cn.n = 112
elements['Cn'] = Cn 

Uut = element()
Uut.origin = "IUPAC systematic element name"
Uut.melting = "(700)11"
Uut.group = 13
Uut.specific_heat_capacity = "–"
Uut.weight = "[286]1"
Uut.density = "(16)11"
Uut.symbol = "Uut"
Uut.period = 7
Uut.abundance = "0 8"
Uut.element = "Ununtrium"
Uut.boiling = "(1400)11"
Uut.electronegativity = "–"
Uut.n = 113
elements['Uut'] = Uut 

Fl = element()
Fl.origin = "Georgy Flyorov, physicist"
Fl.melting = "(340)11"
Fl.group = 14
Fl.specific_heat_capacity = "–"
Fl.weight = "[289]1"
Fl.density = "(14)11"
Fl.symbol = "Fl"
Fl.period = 7
Fl.abundance = "0 8"
Fl.element = "Flerovium"
Fl.boiling = "(420)11"
Fl.electronegativity = "–"
Fl.n = 114
elements['Fl'] = Fl 

Uup = element()
Uup.origin = "IUPAC systematic element name"
Uup.melting = "(700)11"
Uup.group = 15
Uup.specific_heat_capacity = "–"
Uup.weight = "[289]1"
Uup.density = "(13.5)11"
Uup.symbol = "Uup"
Uup.period = 7
Uup.abundance = "0 8"
Uup.element = "Ununpentium"
Uup.boiling = "(1400)11"
Uup.electronegativity = "–"
Uup.n = 115
elements['Uup'] = Uup 

Lv = element()
Lv.origin = "Lawrence Livermore National Laboratory (in Livermore, California) which collaborated with JINR on its synthesis"
Lv.melting = "(708.5)11"
Lv.group = 16
Lv.specific_heat_capacity = "–"
Lv.weight = "[293]1"
Lv.density = "(12.9)11"
Lv.symbol = "Lv"
Lv.period = 7
Lv.abundance = "0 8"
Lv.element = "Livermorium"
Lv.boiling = "(1085)11"
Lv.electronegativity = "–"
Lv.n = 116
elements['Lv'] = Lv 

Uus = element()
Uus.origin = "IUPAC systematic element name"
Uus.melting = "(673)11"
Uus.group = 17
Uus.specific_heat_capacity = "–"
Uus.weight = "[294]1"
Uus.density = "(7.2)11"
Uus.symbol = "Uus"
Uus.period = 7
Uus.abundance = "0 8"
Uus.element = "Ununseptium"
Uus.boiling = "(823)11"
Uus.electronegativity = "–"
Uus.n = 117
elements['Uus'] = Uus 

Uuo = element()
Uuo.origin = "IUPAC systematic element name"
Uuo.melting = "(258)11"
Uuo.group = 18
Uuo.specific_heat_capacity = "–"
Uuo.weight = "[294]1"
Uuo.density = "(5.0)11 13"
Uuo.symbol = "Uuo"
Uuo.period = 7
Uuo.abundance = "0 8"
Uuo.element = "Ununoctium"
Uuo.boiling = "(263)11"
Uuo.electronegativity = "–"
Uuo.n = 118
elements['Uuo'] = Uuo 



